@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -29,6 +29,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 /*
 #define MESSAGES
@@ -45,6 +46,10 @@
 #include <sys/stat.h>
 #include <dirent.h>
 #include <unistd.h>
+
+#ifdef HAVE_INTTYPES_H
+  #include <inttypes.h>
+#endif
     /* Damn it, don't ever use getwd with stupid linux ###jp### */
 #define getwd(aaa) getcwd((aaa),(FS_MAXNAMLEN-2))    
 
@@ -95,18 +100,18 @@
 static String unknownList[] = {"<cannot enter directory>",NULL};
 static String cannotopenList[] = {"<cannot read directory>",NULL};
 
-static void FS_textfieldFocusAction();
-static void FS_textfieldBackSpaceAction();
-static void FS_textfieldDeleteAction();
-static void FS_listAction();
-static void FS_preferButtonAction();
+static void FS_textfieldFocusAction(Widget,XEvent*,String*,Cardinal*);
+static void FS_textfieldBackSpaceAction(Widget,XEvent*,String*,Cardinal*);
+static void FS_textfieldDeleteAction(Widget,XEvent*,String*,Cardinal*);
+static void FS_listAction(Widget,XEvent*,String*,Cardinal*);
+static void FS_preferButtonAction(Widget,XEvent*,String*,Cardinal*);
 
 static XtActionsRec file_selectionActionsTable[] = {
-       { "FS_textfieldFocusAction",  (XtActionProc) FS_textfieldFocusAction },
-       { "FS_textfieldBackSpaceAction", (XtActionProc) FS_textfieldBackSpaceAction },
-       { "FS_textfieldDeleteAction", (XtActionProc) FS_textfieldDeleteAction },
-       { "FS_preferButton",          (XtActionProc) FS_preferButtonAction },
-       { "List",      (XtActionProc) FS_listAction }
+       { "FS_textfieldFocusAction",  FS_textfieldFocusAction },
+       { "FS_textfieldBackSpaceAction", FS_textfieldBackSpaceAction },
+       { "FS_textfieldDeleteAction", FS_textfieldDeleteAction },
+       { "FS_preferButton",          FS_preferButtonAction },
+       { "List",      FS_listAction }
 };
 
 static String list_translations =
@@ -347,16 +352,23 @@ static XtResource resources[] = {
 #undef offset
 #undef lay_offset
 
-static Boolean SetValues();
-static void ClassInitialize(), Initialize(), Realize(), Destroy();
-static void filtersProc(),dirsProc(),rescanProc();
-static void TopDirSelectionProc(), CurDirSelectionProc(), SubDirSelectionProc();
-static void changeLists();
-static Widget BuildMenu();
-static void SetDirectoryView();
-static void CreateTextField();
-static void SetPreferredButton();
-static void CreateList();
+static Boolean SetValues(Widget,Widget,Widget,ArgList,Cardinal*);
+static void ClassInitialize(void);
+static void Initialize(Widget,Widget,ArgList,Cardinal*);
+static void Realize(Widget,XtValueMask*,XSetWindowAttributes*);
+static void Destroy(Widget);
+static void filtersProc(Widget,XtPointer,XtPointer);
+static void dirsProc(Widget,XtPointer,XtPointer);
+static void rescanProc(Widget,XtPointer,XtPointer);
+static void TopDirSelectionProc(Widget,XtPointer,XtPointer);
+static void CurDirSelectionProc(Widget,XtPointer,XtPointer);
+static void SubDirSelectionProc(Widget,XtPointer,XtPointer);
+static void changeLists(FileSelectionWidget);
+static Widget BuildMenu(Widget,String,String,XtCallbackProc);
+static void SetDirectoryView(FileSelectionWidget,char*);
+static void CreateTextField(Widget*,Widget*,char*,XtTranslations,String,Widget);
+static void SetPreferredButton(Widget,int,int);
+static void CreateList(Widget*,Widget*,Widget*,Widget*,Widget*,XtTranslations,String,Widget);
 
 FileSelectionClassRec file_selectionClassRec = {
   {
@@ -435,7 +447,7 @@ WidgetClass file_selectionWidgetClass = (WidgetClass) &file_selectionClassRec;
 -------------------------------------------------------------------------------*/
 
 static void 
-ClassInitialize()
+ClassInitialize(void)
 {
    BEGINMESSAGE(ClassInitialize)
    XawInitializeWidgetSet();
@@ -565,7 +577,7 @@ static void Realize (w, valueMask, attrs)
    FS_WIDGET w;
    BEGINMESSAGE(Realize)
    (*file_selectionWidgetClass->core_class.superclass->core_class.realize)(w, valueMask, attrs);
-   changeLists(w);
+   changeLists((FileSelectionWidget)w);
    FS_textfieldFocusAction(FS_PATH, NULL, NULL, NULL);
    ENDMESSAGE(Realize)
 }
@@ -886,7 +898,6 @@ static void SetPreferredButton(w,position,install)
    FS_WIDGET 	w;
    char 	name[10];
    Widget 	button;
-   USE_Arg(2);
 
    BEGINMESSAGE(SetPreferredButton)
 
@@ -1045,9 +1056,9 @@ static void FS_listAction(w, event, params, nparams)
     if (!scrolling) {
       int entry = VlistEntryOfPosition(list,(int)event->xbutton.y);
       if (entry >=0 && entry < VlistEntries(list)) {
-	if      (list == FS_CURLIST) CurDirSelectionProc(list,NULL,(XtPointer)entry);
-	else if (list == FS_SUBLIST) SubDirSelectionProc(list,NULL,(XtPointer)entry);
-	else if (list == FS_TOPLIST) TopDirSelectionProc(list,NULL,(XtPointer)entry);
+	if      (list == FS_CURLIST) CurDirSelectionProc(list,NULL,(XtPointer)(intptr_t)entry);
+	else if (list == FS_SUBLIST) SubDirSelectionProc(list,NULL,(XtPointer)(intptr_t)entry);
+	else if (list == FS_TOPLIST) TopDirSelectionProc(list,NULL,(XtPointer)(intptr_t)entry);
       }
     }
   }
@@ -1327,12 +1338,8 @@ static void changeLists(FS_FILE_SELECTION)
 ----------------------------------------------------------------------*/
 
 static void
-SetIncompleteDirectoryView(w,list)
-   Widget	w;
-   String	*list;
+SetIncompleteDirectoryView(FileSelectionWidget fs, String *list)
 {
-   FS_WIDGET 	w;
-
    BEGINMESSAGE(SetIncompleteDirectoryView)
    changeList(FS_CURLIST, list, 1);
    chdir(APP_DIR);
@@ -1397,11 +1404,10 @@ CombineToPath(path,dir,file)
    SetDirectoryView
 ----------------------------------------------------------------------*/
 
-static void SetDirectoryView(w,dir)
-   Widget	w;
+static void SetDirectoryView(fs,dir)
+   FileSelectionWidget	fs;
    char *dir;
 {
-   FS_WIDGET 		w;
    DIR			*dirp;
    struct dirent	*dp;
    String  		str;
@@ -1460,8 +1466,8 @@ static void SetDirectoryView(w,dir)
    if (error) {
      INFIMESSAGE(cannot analyze directory,error)
      changeLists(FS_FILE_SELECTION);
-     if (error==1) SetIncompleteDirectoryView(w,unknownList); 
-     else          SetIncompleteDirectoryView(w,cannotopenList);
+     if (error==1) SetIncompleteDirectoryView(fs,unknownList); 
+     else          SetIncompleteDirectoryView(fs,cannotopenList);
      chdir(APP_DIR);
      ENDMESSAGE(SetDirectoryView)
      return;
@@ -1644,7 +1650,7 @@ dirsProc(w, client_data, call_data)
     if (TMP_DIR_RESOURCE) newpath = TMP_DIR_RESOURCE;
     else newpath = HOME;
   }
-  SetDirectoryView((Widget)FS_FILE_SELECTION,newpath);
+  SetDirectoryView(FS_FILE_SELECTION,newpath);
   ClipWidgetSetCoordinates(FS_CURCLIP, 0, 0);
   ENDMESSAGE(dirsProc)
 }
@@ -1660,7 +1666,7 @@ TopDirSelectionProc(w, client_data, call_data)
   XtPointer	client_data, call_data;
 {
   FS_WIDGET XtParent(XtParent(XtParent(XtParent(w))));
-  int item = (int) call_data;
+  int item = (int)(intptr_t)call_data;
   char newpath[FS_MAXNAMLEN];
    
   BEGINMESSAGE(TopDirSelectionProc)
@@ -1706,7 +1712,7 @@ CurDirSelectionProc(w, client_data, call_data)
 {
    FS_WIDGET	XtParent(XtParent(XtParent(XtParent(w))));
    char		name[10];
-   int item = (int) call_data;
+   int item = (int)(intptr_t) call_data;
 
    BEGINMESSAGE(CurDirSelectionProc)
 
@@ -1748,7 +1754,7 @@ SubDirSelectionProc(w, client_data, call_data)
   Widget	w;
   XtPointer	client_data, call_data;
 {
-  int item = (int)call_data;
+  int item = (int)(intptr_t) call_data;
   FS_WIDGET XtParent(XtParent(XtParent(XtParent(w))));
   char newpath[FS_MAXNAMLEN];
    
@@ -1774,7 +1780,7 @@ SubDirSelectionProc(w, client_data, call_data)
       appendDirEndSeparator(newpath);
     }
     SMESSAGE(newpath)
-    SetDirectoryView((Widget)FS_FILE_SELECTION,newpath);
+    SetDirectoryView(FS_FILE_SELECTION,newpath);
     ClipWidgetSetCoordinates(FS_CURCLIP, 0, 0);
   }
   ENDMESSAGE(SubDirSelectionProc)
@@ -1845,15 +1851,15 @@ SMESSAGE(XtName(p))
   {
     Widget clip=NULL,aaa=NULL,scroll=NULL;
     FS_WIDGET p;
-    int style = (int)client_data;
+    int style = (int)(intptr_t)client_data;
     if      (s[0] == 'c') { clip = FS_CURCLIP; aaa = FS_CURAAA; scroll = FS_CURSCROLL; }
     else if (s[0] == 's') { clip = FS_SUBCLIP; aaa = FS_SUBAAA; scroll = FS_SUBSCROLL; }
     else style=0;
     if (style == SCROLL_SCROLLPROC || style == SCROLL_JUMPPROC) {
       int x,y;
       x = (int) aaa->core.x;
-      if (((int)client_data)==1) y = (int) aaa->core.y - (int)call_data;
-      else                       y = (int)(-*((float*)call_data) * aaa->core.height);
+      if (((int)(intptr_t)client_data)==1) y = (int)(intptr_t) aaa->core.y - (int)(intptr_t)call_data;
+      else                               y = (int)(-*((float*)call_data) * aaa->core.height);
       ClipWidgetSetCoordinates(clip, x, y);
     } else if (style == SCROLL_CLIPREPORT) {
       float h = (float)aaa->core.height;
