@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -31,6 +31,7 @@
  * February 1995, March 1996 ###jp###
  *
 */
+#include "ac_config.h"
 
 
 /*
@@ -139,6 +140,8 @@ static XtResource resources[] = {
 	  offset(palette), XtRImmediate, (XtPointer)XtPaletteColor },
     { XtNquiet, XtCQuiet, XtRBoolean, sizeof(Boolean),
 	  offset(quiet), XtRImmediate, (XtPointer)True },
+    { XtNinfoVerbose, XtCinfoVerbose, XtRinfoVerbose, sizeof(int),
+	  offset(infoVerbose), XtRImmediate, (XtPointer)0 },
     { XtNrightMargin, XtCMargin, XtRInt, sizeof(int),
 	  offset(right_margin), XtRImmediate, (XtPointer)0 },
     { XtNscrollCursor, XtCCursor, XtRCursor, sizeof(XtPointer),
@@ -170,30 +173,30 @@ static XtResource resources[] = {
 #undef offset
 };
 
-static void Message();
-static void Notify();
-static void action_changeCursor();
-static void Input();
-static void Output();
+static void Message(Widget,XEvent*,String*,Cardinal*);
+static void Notify(Widget,XEvent*,String*,Cardinal*);
+static void action_changeCursor(Widget,XEvent*,String*,Cardinal*);
+static void Input(XtPointer,int *,XtInputId*);
+static void Output(XtPointer,int*,XtInputId*);
 
-static void ClassInitialize();
-static void ClassPartInitialize();
-static void Initialize();
-static void Realize();
-static void Redisplay();
-static void Destroy();
-static void Resize();
-static Boolean SetValues();
-static XtGeometryResult QueryGeometry();
+static void ClassInitialize(void);
+static void ClassPartInitialize(WidgetClass);
+static void Initialize(Widget,Widget,ArgList,Cardinal*);
+static void Realize(Widget,XtValueMask*,XSetWindowAttributes*);
+static void Redisplay(Widget,XEvent *,Region);
+static void Destroy(Widget);
+static void Resize(Widget);
+static Boolean SetValues(Widget,Widget,Widget,ArgList,Cardinal*);
+static XtGeometryResult QueryGeometry(Widget,XtWidgetGeometry *,XtWidgetGeometry *);
 
-static void Layout();
-static Boolean ComputeSize();
-static void SetBackground();
-static Boolean Setup();
-static void StartInterpreter();
-static void StopInterpreter();
-static void InterpreterFailed();
-static void ChangeCursor();
+static void Layout(Widget,Boolean,Boolean);
+static Boolean ComputeSize(Widget,Boolean,Boolean,Dimension*,Dimension*);
+static void SetBackground(Widget,Bool);
+static Boolean Setup(Widget);
+static void StartInterpreter(Widget);
+static void StopInterpreter(Widget);
+static void InterpreterFailed(Widget);
+static void ChangeCursor(GhostviewWidget,int);
 
 static XtActionsRec actions[] =
 {
@@ -273,10 +276,11 @@ static void Copy_pixmap(w)
       int scr = DefaultScreen(dpy);
       GC gc = DefaultGC(dpy, scr);
       Window win = XtWindow(w);
-      int x, gwidth, gheight;
+      int x;
+      unsigned int gwidth, gheight, dummy;
       Window r;
     
-      XGetGeometry(dpy,win, &r,&x,&x,&gwidth, &gheight,&x,&x);
+      XGetGeometry(dpy, win, &r, &x, &x, &gwidth, &gheight, &dummy, &dummy);
       XCopyArea(dpy, pix, win, gc, 0,0, gwidth, gheight, 0,0);
     }
   }      
@@ -289,10 +293,11 @@ static void Realize_pixmap(w)
         Display *dpy = XtDisplay(w);
         int scr = DefaultScreen(dpy);
         Window win = XtWindow(w);
-        int x, gwidth, gheight;
+        int x;
+	unsigned int gwidth, gheight, dummy;
         Window r;
 
-        XGetGeometry(dpy,win, &r,&x,&x,&gwidth, &gheight,&x,&x);
+        XGetGeometry(dpy, win, &r, &x, &x, &gwidth, &gheight, &dummy, &dummy);
 /*        printf("Realize_pixmap %d %d\n", gwidth, gheight);         */
         pix =  XCreatePixmap(dpy, win, gwidth, gheight, DefaultDepth(dpy,scr));
     } 
@@ -688,7 +693,7 @@ Output(client_data, source, id)
 /*###################################################################################*/
 
 static void
-ClassInitialize()
+ClassInitialize(void)
 {
     BEGINMESSAGE(ClassInitialize)
 #ifndef GV_CODE
@@ -892,8 +897,7 @@ Resize(w)
 /*###################################################################################*/
 
 static Boolean
-SetValues(current, request, new)
-    Widget current, request, new;
+SetValues(Widget current, Widget request, Widget new, ArgList unused1, Cardinal *unused2)
 {
     GhostviewWidget cgvw = (GhostviewWidget) current;
     GhostviewWidget rgvw = (GhostviewWidget) request;
@@ -954,6 +958,7 @@ SetValues(current, request, new)
 	   strcmp(cgvw->ghostview.interpreter, ngvw->ghostview.interpreter)	||
 	   strcmp(carguments, rarguments)					||
 	   (cgvw->ghostview.quiet != ngvw->ghostview.quiet)			||
+	   (cgvw->ghostview.infoVerbose != ngvw->ghostview.infoVerbose)			||
 	   (cgvw->ghostview.safer != ngvw->ghostview.safer)			||
 	   strcmp(cfilename, rfilename)						||
            (cgvw->ghostview.orientation != ngvw->ghostview.orientation)		||
@@ -1382,6 +1387,7 @@ StartInterpreter(w)
     char *dptr;
     int argc = 0;
     int ret;
+    String filename = 0;
 
     BEGINMESSAGE(StartInterpreter)
 
@@ -1451,7 +1457,6 @@ StartInterpreter(w)
 	}
     }
 
-    String filename = 0;
 #   ifdef ALLOW_PDF
     if (gvw->ghostview.filename && strcmp(gvw->ghostview.filename,"-")) {
           if ( *(gvw->ghostview.filename) == '-' ) {
@@ -1517,8 +1522,8 @@ StartInterpreter(w)
          } else {
            sprintf(buf, "%ld", XtWindow(w));
          }
-	setenv("GHOSTVIEW", buf, True);
-	setenv("DISPLAY", XDisplayString(XtDisplay(w)), True);
+	gnu_gv_setenv("GHOSTVIEW", buf, True);
+	gnu_gv_setenv("DISPLAY", XDisplayString(XtDisplay(w)), True);
 	if (gvw->ghostview.filename == NULL) {
 	    close(std_in[1]);
 	    dup2(std_in[0], 0);
