@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -30,6 +30,8 @@
 **
 */
 
+#include "ac_config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 /*
@@ -96,13 +98,15 @@ static XtResource resources[] = {
 };
 #undef offset
 
-static Boolean SetValues();
-static void Initialize(), Redisplay();
-static void Destroy(), PaintVlistWidget();
-static void ClassInitialize();
-static void Resize();
-static void PaintMarkOfEntry();
-static void PaintMarkMarkOfEntry();
+static Boolean SetValues(Widget,Widget,Widget,ArgList,Cardinal*);
+static void Initialize(Widget,Widget,ArgList,Cardinal*);
+static void Redisplay(Widget,XEvent*,Region);
+static void Destroy(Widget);
+static void PaintVlistWidget(Widget,XEvent*,Region);
+static void ClassInitialize(void);
+static void Resize(Widget);
+static void PaintMarkOfEntry(Widget,Region,int,int,Boolean);
+static void PaintMarkMarkOfEntry(Widget,Region,int,Boolean);
 
 
 #define SuperClass ((LabelWidgetClass)&labelClassRec)
@@ -163,7 +167,7 @@ WidgetClass vlistWidgetClass = (WidgetClass) &vlistClassRec;
 /* ClassInitialize */
 /*---------------------------------------------------*/
 
-static void ClassInitialize()
+static void ClassInitialize(void)
 {
   BEGINMESSAGE(ClassInitialize)
   XawInitializeWidgetSet();
