@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -28,11 +28,8 @@
 *+            Jose E. Marchesi (jemarch@gnu.org)
 **            GNU Project
 */
+#include "ac_config.h"
 
-/*
-#define MESSAGES
-#define MESSAGES1
-*/
 #include "message.h"
 
 #include "config.h"
@@ -41,6 +38,10 @@
 #include <stdlib.h>
 #include <math.h>
 
+#ifdef HAVE_INTTYPES_H
+  #include <inttypes.h>
+#endif
+
 #include "paths.h"
 #include INC_X11(Intrinsic.h)
 #include INC_X11(StringDefs.h)
@@ -93,6 +94,12 @@ action_shellConfigureNotify(w, event, params, num_params)
      IIMESSAGE(new_width,new_height)
   }
   if (new_width && new_height) {
+    if (gv_scales[gv_scale]->scale <= 0 && !app_res.auto_resize)
+    {
+       misc_savePagePosition();
+       show_page(REQUEST_NEW_SCALE,NULL);
+       misc_resetPagePosition();
+    }
     if (width != new_width || height != new_height) {
        misc_setPageMarker(0,2,event,True); /* bring selected in sight */
        width = new_width;
@@ -897,7 +904,7 @@ action_setPageMark(w, event, params, num_params)
     else if (!strcmp(params[1],mark))      spm=spm|SPM_MARK;
     else                                   spm=spm|SPM_UNMARK;
    
-    cb_setPageMark((Widget)NULL,(XtPointer)spm,NULL);
+    cb_setPageMark((Widget)NULL,(XtPointer)(intptr_t)spm,NULL);
 
     ENDMESSAGE(action_setPageMark)
 }
@@ -945,7 +952,7 @@ action_setScale(w, event, params, num_params)
       if (i<0) i = (-i)|SCALE_MIN;
       i |= SCALE_REL;
     }
-    cb_setScale(w, (XtPointer)i, NULL);
+    cb_setScale(w, (XtPointer)(intptr_t)i, NULL);
     ENDMESSAGE(action_setScale)
 }
 
@@ -971,7 +978,7 @@ action_setOrientation(w, event, params, num_params)
        return;
     }
     o = doc_convStringToDocOrient(params[0]);
-    if (o != O_UNSPECIFIED) cb_setOrientation(w, (XtPointer)o, NULL);
+    if (o != O_UNSPECIFIED) cb_setOrientation(w, (XtPointer)(intptr_t)o, NULL);
     ENDMESSAGE(action_setOrientation)
 }
 
@@ -999,7 +1006,7 @@ action_setPagemedia(w, event, params, num_params)
     }
 
     m = doc_convStringToPageMedia(doc,params[0]);
-    if (m!= MEDIA_ID_INVALID) cb_setPagemedia(w, (XtPointer)m, NULL);
+    if (m!= MEDIA_ID_INVALID) cb_setPagemedia(w, (XtPointer)(intptr_t)m, NULL);
 
     ENDMESSAGE(action_setPagemedia)
 }
