@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -28,6 +28,7 @@
 **            Jose E. Marchesi (jemarch@gnu.org)
 **            GNU Project
 */
+#include "ac_config.h"
 
 /*
 #define MESSAGES
@@ -41,6 +42,10 @@
 #include <time.h>
 #include <ctype.h>
 
+#ifdef HAVE_INTTYPES_H
+  #include <inttypes.h>
+#endif
+
 #ifndef BUFSIZ
 #   define BUFSIZ 1024
 #endif
@@ -152,8 +157,8 @@ cb_newtocScrollbar(w, client_data, call_data)
 
   BEGINMESSAGE(cb_newtocScrollbar)
   x = (int) newtocControl->core.x;
-  if (((int)client_data)==1) {
-    int dy = (int)call_data;
+  if (((int)(intptr_t)client_data)==1) {
+    int dy = (int)(intptr_t)call_data;
     y = (int) newtocControl->core.y - dy;
   } else {
     float *percent = (float *) call_data;
@@ -262,7 +267,7 @@ void cb_useBackingPixmap(w, client_data, call_data)
   Widget w;
   XtPointer client_data, call_data;
 {
-  int i = (int)client_data;
+  int i = (int)(intptr_t)client_data;
 
   BEGINMESSAGE(cb_useBackingPixmap)
   if (i&1) {
@@ -366,7 +371,7 @@ cb_checkFile(w, client_data, call_data)
     int changed;
 
     BEGINMESSAGE(cb_checkFile)
-    changed = check_file(((int)client_data));
+    changed = check_file(((int)(intptr_t)client_data));
     if (changed==1)
     {
        cb_stopInterpreter(page,NULL,NULL);
@@ -392,7 +397,7 @@ static void watch_file (client_data, idp)
 
   BEGINMESSAGE(watch_file)
   /* notification after timeout */
-  if ((int)client_data && app_res.watch_file) {
+  if ((int)(intptr_t)client_data && app_res.watch_file) {
     if (!file_fileIsNotUseful(gv_filename)) {
       int error;
       String s;
@@ -509,7 +514,7 @@ cb_print(w, client_data, call_data)
        return;
     }
 
-    gv_print_mode = (int)client_data;
+    gv_print_mode = (int)(intptr_t)client_data;
     pagelist=get_pagelist(&gv_print_mode);
     if (pagelist) GV_XtFree(pagelist);
     if (gv_print_mode==PAGE_MODE_INVALID) {
@@ -627,7 +632,7 @@ cb_save(w, client_data, call_data)
 
     BEGINMESSAGE(cb_save)
 
-    gv_save_mode = (int)client_data;
+    gv_save_mode = (int)(intptr_t)client_data;
     pagelist=get_pagelist(&gv_save_mode);
     if (pagelist) GV_XtFree(pagelist);
     if (gv_save_mode==PAGE_MODE_INVALID) {
@@ -711,7 +716,7 @@ cb_doSave(w, client_data, call_data)
     int type;
 
     BEGINMESSAGE(cb_doSave)
-    if (client_data) type = (int)client_data;
+    if (client_data) type = (int)(intptr_t)client_data;
     else type = FILE_TYPE_PS;
 
     name = XawFileSelectionGetPath(FileSel);
@@ -938,7 +943,7 @@ cb_positionPage(w, client_data, call_data)
   cow = (int)control->core.width;
   coh = (int)control->core.height;
 
-  if ((int)client_data) center = True;
+  if ((int)(intptr_t)client_data) center = True;
   if (!center) have_pagepos=misc_restorePagePosition(&px,&py);
   if (app_res.auto_center == True) center = True;
 
@@ -979,7 +984,7 @@ cb_setPageMark(w, client_data, call_data)
     Widget w;
     XtPointer client_data, call_data;
 {
-    int r=(int)client_data;
+    int r=(int)(intptr_t)client_data;
     int entry=XawVlistInvalid,change=XawVlistInvalid;
 
     BEGINMESSAGE(cb_setPageMark)
@@ -1032,7 +1037,7 @@ cb_setScale(w, client_data, call_data)
   Widget w;
   XtPointer client_data, call_data;
 {
-  int i=(int)client_data;
+  int i=(int)(intptr_t)client_data;
 
   BEGINMESSAGE(cb_setScale)
   i = scale_checkScaleNum(gv_scales,i);
@@ -1057,7 +1062,7 @@ cb_setOrientation(w, client_data, call_data)
     Widget w;
     XtPointer client_data, call_data;
 {
-    int o = (int) client_data;
+    int o = (int)(intptr_t) client_data;
     int changed = 1;
 
     BEGINMESSAGE(cb_setOrientation)
@@ -1087,7 +1092,10 @@ cb_setOrientation(w, client_data, call_data)
     if (!call_data) {
       if (changed) {
 	misc_savePagePosition();
-	show_page(REQUEST_NEW_ORIENTATION,NULL);
+	if (gv_scales[gv_scale]->scale > 0 || app_res.auto_resize)
+	   show_page(REQUEST_NEW_ORIENTATION,NULL);
+	else
+	   show_page(REQUEST_SETUP,NULL);
 	misc_resetPagePosition();
       }
     }
@@ -1103,7 +1111,7 @@ cb_setPagemedia(w, client_data, call_data)
    Widget w;
    XtPointer client_data, call_data;
 {
-   int media = (int)client_data;
+   int media = (int)(intptr_t)client_data;
    int media_bbox = doc ? doc->nummedia : 0;
 
    BEGINMESSAGE(cb_setPagemedia)
@@ -1119,7 +1127,10 @@ cb_setPagemedia(w, client_data, call_data)
      gv_pagemedia = media;
    }
    if (!call_data) {
-     show_page(REQUEST_NEW_PAGEMEDIA,NULL);
+     if (gv_scales[gv_scale]->scale > 0 || app_res.auto_resize)
+	   show_page(REQUEST_NEW_PAGEMEDIA,NULL);
+     else
+	   show_page(REQUEST_SETUP,NULL);
    }
    ENDMESSAGE(cb_setPagemedia)
 }
