@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -30,7 +30,6 @@
 **
 */
 
-
 #ifndef _GV_CONFIG_H_
 #define _GV_CONFIG_H_
 
@@ -68,6 +67,9 @@ Inline copies of optional external files.
 #ifdef USE_FALLBACK_STYLES
 #   define FALLBACK_STYLE_1_DAT         "gv_spartan.dat"
 #   define FALLBACK_STYLE_1_H           "gv_spartan.h"
+
+#   define FALLBACK_STYLE_2_DAT         "gv_widgetless.dat"
+#   define FALLBACK_STYLE_2_H           "gv_widgetless.h"
 #endif
 
 #define FALLBACK_ICON_PIXMAP         "gv_icon.xbm"
@@ -118,9 +120,7 @@ Miscellaneous defaults
 #define EXIT_STATUS_ERROR	1
 #define EXIT_STATUS_FATAL    -1
 
+#include "setenv.h"
+
+
 #endif /* _GV_CONFIG_H_ */
-
-
-
-
-
