@@ -6,7 +6,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -28,6 +28,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 /*
 #define MESSAGES
@@ -37,6 +38,7 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <stdlib.h>
 
 #include "paths.h"
 #include INC_X11(Intrinsic.h)
@@ -76,8 +78,6 @@ void cb_popupInfoPopup(w, client_data, call_data)
    Widget	w;
    XtPointer	client_data, call_data;
 {
-   if (getenv("GV_COMPLETLY_SILENT")) return; /* This feature will be replaced 
-                                           in rel. 3.6.5 by a real solution */
    BEGINMESSAGE(cb_popupInfoPopup)
    if (!infoPopupCreated) { makeInfoPopup(); }
    if (infoPopupVisible==True) {INFMESSAGE(InfoPopup already up) ENDMESSAGE(popupInfoPopup) return; }
@@ -139,7 +139,9 @@ void cb_appendInfoPopup(w, client_data, call_data)
     XtSetArg(args[1], XtNinsertPosition, info_length);	n++;
     XtSetValues(infotext,args,n);
     XawTextEnableRedisplay(infotext);
-    if (!infoPopupVisible) cb_popupInfoPopup((Widget)NULL,(XtPointer)NULL,(XtPointer)NULL);
+    if (!infoPopupVisible && gv_infoVerbose)
+       if (gv_infoVerbose == 2 || strstr((char*)call_data, "Error:"))
+          cb_popupInfoPopup((Widget)NULL,(XtPointer)NULL,(XtPointer)NULL);
     ENDMESSAGE(cb_appendInfoPopup)
 }
 
@@ -178,7 +180,7 @@ void cb_resetInfoPopup(w, client_data, call_data)
    makeInfoPopup
 ###############################################################################*/
 
-void makeInfoPopup()
+void makeInfoPopup(void)
 {
    Arg          args[12];
    Cardinal     n;
