@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -29,6 +29,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 #define _GV_MAIN_C_
 
@@ -46,11 +47,16 @@
 #include <math.h>
 #include <getopt.h>
 
+#ifdef HAVE_INTTYPES_H
+  #include <inttypes.h>
+#endif
+
 #include "paths.h"
 #include INC_X11(Intrinsic.h)
 #include INC_X11(cursorfont.h)
 #include INC_X11(StringDefs.h)
 #include INC_X11(Shell.h)
+#include INC_X11(Xatom.h)
 #include INC_XAW(Cardinals.h)
 #include INC_XAW(SimpleMenu.h)
 #include INC_XAW(SmeBSB.h)
@@ -158,12 +164,18 @@ enum
     GRAYSCALE_ARG,
     HELP_ARG,
     QUIET_ARG,
+    INFOSILENT_ARG,
+    INFOERRORS_ARG,
+    INFOALL_ARG,
+    FULLSCREEN_ARG,
+    PRESENTATION_ARG,
     MONOCHROME_ARG,
     NOQUIET_ARG,
     MEDIA_ARG,
     ORIENTATION_ARG,
     PAGE_ARG,
     SPARTAN_ARG,
+    WIDGETLESS_ARG,
     USAGE_ARG,
     VERSION_ARG
   };
@@ -198,6 +210,11 @@ static struct option const GNU_longOptions[] =
     {"color", no_argument, NULL, COLOR_ARG},
     {"help", no_argument, NULL, HELP_ARG},
     {"quiet", no_argument, NULL, QUIET_ARG},
+    {"infoSilent", no_argument, NULL, INFOSILENT_ARG},
+    {"infoErrors", no_argument, NULL, INFOERRORS_ARG},
+    {"infoAll", no_argument, NULL, INFOALL_ARG},
+    {"fullscreen", no_argument, NULL, FULLSCREEN_ARG},
+    {"presentation", no_argument, NULL, PRESENTATION_ARG},
     {"monochrome", no_argument, NULL, MONOCHROME_ARG},
     {"noquiet", no_argument, NULL, NOQUIET_ARG},
     {"media", required_argument, NULL, MEDIA_ARG},
@@ -205,6 +222,7 @@ static struct option const GNU_longOptions[] =
     {"page", required_argument, NULL, PAGE_ARG},
     {"usage", no_argument, NULL, USAGE_ARG},
     {"spartan", no_argument, NULL, SPARTAN_ARG},
+    {"widgetless", no_argument, NULL, WIDGETLESS_ARG},
     {"version", no_argument, NULL, VERSION_ARG},
     {NULL, 0, NULL, 0}
   };
@@ -280,11 +298,11 @@ dummyCvtStringToPixmap(dpy, args, num_args, fromVal, toVal,converter_data)
 
 /*### Procedure and Macro Declarations ###########################################*/
 
-static void  main_createMenu();
-void main_setGhostscriptResources();
-void main_setInternResource();
-void main_setResolutions();
-void main_createScaleMenu();
+static void  main_createMenu(MenuEntry*,Widget*,Cardinal*);
+void main_setGhostscriptResources(XrmDatabase);
+void main_setInternResource(XrmDatabase,String*,char*);
+void main_setResolutions(int);
+void main_createScaleMenu(void);
 
 #ifdef max
 #   undef max
@@ -348,12 +366,14 @@ int main(argc, argv)
     color_p = 0;
     grayscale_p = 0;
     quiet_p = 0;
+    infoverbose_p = -1;
     monochrome_p = 0;
     noquiet_p = 0;
     media_p = 0;
     orientation_p = 0;
     page_p = 0;
     spartan_p = 0;
+    widgetless_p = 0;
     center_p = 0;
     nocenter_p = 0;
     scale_p = 0;
@@ -372,6 +392,8 @@ int main(argc, argv)
     ad_p = 0;
     style_p = 0;
     arguments_p = 0;
+    fullscreen_p = 0;
+    ascale_p = 1.0;
 
 
     /*###  initializing toolkit and the application context ########*/
@@ -393,17 +415,13 @@ int main(argc, argv)
      const char *xufsp="XUSERFILESEARCHPATH";
      char *xuf;
      xuf = getenv(xufsp); if (xuf) xuf = GV_XtNewString(xuf);
-     setenv(xufsp,"___",1);
+     gnu_gv_setenv(xufsp,"___",1);
      gv_display = XtOpenDisplay(app_con,NULL,NULL,gv_class,NULL,0,&argc,argv);
 
-     if (xuf) { setenv(xufsp,xuf,1); GV_XtFree(xuf); } else unsetenv(xufsp);
-     if (!gv_display) {
-       fprintf(stderr, "%s: Unable to open the display.\n", GV_APPLICATION_NAME);
-       exit(EXIT_STATUS_ERROR);
-     }
-     XtGetApplicationNameAndClass(gv_display,&gv_name,&gv_class);
+     if (xuf) { gnu_gv_setenv(xufsp,xuf,1); GV_XtFree(xuf); } else gnu_gv_unsetenv(xufsp);
+     if (gv_display)
+        XtGetApplicationNameAndClass(gv_display,&gv_name,&gv_class);
      SMESSAGE(gv_name) SMESSAGE(gv_class)
-
    }
 
    /*### Manage GNU command line arguments ########################*/
@@ -422,8 +440,17 @@ int main(argc, argv)
 	   opt_counter++;
 	   break;
 	 case SCALE_ARG:
-	   scale_p = 1;
-	   scale_value = optarg;
+	   if (strstr(optarg, "."))
+	   {
+	      scale_p = 1;
+	      scale_value = "-1002";
+	      sscanf(optarg, "%f", &ascale_p);
+	   }
+	   else
+	   {
+	      scale_p = 1;
+	      scale_value = optarg;
+	   }
 	   opt_counter++;
 	   break;
 	 case MAGSTEP_ARG:
@@ -444,6 +471,18 @@ int main(argc, argv)
 	   noresize_p = 1;
 	   opt_counter++;
 	   break;
+	 case FULLSCREEN_ARG:
+	   fullscreen_p = 1;
+	   opt_counter++;
+	   break;
+	 case PRESENTATION_ARG:
+	   fullscreen_p = 1;
+	   noresize_p = 1;
+	   widgetless_p = 1;
+	   scale_p = 1;
+	   scale_value = "-1000";
+	   opt_counter++;
+	   break;
 	 case SWAP_ARG:
 	   swap_p = 1;
 	   opt_counter++;
@@ -531,6 +570,18 @@ int main(argc, argv)
 	   quiet_p = 1;
 	   opt_counter++;
 	   break;
+	 case INFOSILENT_ARG:
+	   infoverbose_p = 0;
+	   opt_counter++;
+	   break;
+	 case INFOERRORS_ARG:
+	   infoverbose_p = 1;
+	   opt_counter++;
+	   break;
+	 case INFOALL_ARG:
+	   infoverbose_p = 2;
+	   opt_counter++;
+	   break;
 	 case MONOCHROME_ARG:
 	   monochrome_p = 1;
 	   opt_counter++;
@@ -573,6 +624,11 @@ int main(argc, argv)
 	   opt_counter++;
 	   break;
 
+	 case WIDGETLESS_ARG:
+	   widgetless_p = 1;
+	   opt_counter++;
+	   break;
+
 	 case VERSION_ARG:
 	   /* Show the program version */
 	   fprintf(stdout,"%s\n", versionIdentification[0]);
@@ -587,6 +643,10 @@ int main(argc, argv)
 	 }
      }
 
+     if (!gv_display) {
+       fprintf(stderr, "%s: Unable to open the display.\n", GV_APPLICATION_NAME);
+       exit(EXIT_STATUS_ERROR);
+     }
    /*### getting resources ############################################*/
    gv_database = resource_buildDatabase (gv_display,
                                          gv_class,
@@ -654,11 +714,56 @@ int main(argc, argv)
     gv_scales_res = GV_XtNewString(gv_scales_res);
     gv_scales = scale_parseScales(gv_scales_res);
     gv_scale_current = gv_scale_base_current = -1;
-    if (app_res.scale < 0) app_res.scale = (-app_res.scale)|SCALE_MIN;
-    app_res.scale &= (SCALE_VAL|SCALE_MIN);
-    gv_scale = scale_checkScaleNum(gv_scales,app_res.scale|SCALE_REL);
-    if (gv_scale < 0) gv_scale = scale_checkScaleNum(gv_scales,0|SCALE_REL);
-    gv_scale &= SCALE_VAL;
+
+    gv_ascale = 1.0;
+
+    if (app_res.scale == -1000)
+    {
+       int j;
+       gv_scale = scale_checkScaleNum(gv_scales,0|SCALE_REL) & SCALE_VAL;
+       for (j=0; gv_scales[j]; j++)
+          if (!gv_scales[j]->scale)
+	  {
+	     gv_scale = j;
+	     break;
+          }
+    }
+    else if (app_res.scale == -1001)
+    {
+       int j;
+
+       gv_scale = scale_checkScaleNum(gv_scales,0|SCALE_REL) & SCALE_VAL;
+
+       for (j=0; gv_scales[j]; j++)
+          if (fabs(gv_scales[j]->scale+1) <= 0.001)
+	  {
+	     gv_scale = j;
+	     break;
+          }
+       gv_ascale = sqrt(ascale_p);
+    }
+    else if (app_res.scale == -1002)
+    {
+       int j;
+
+       gv_scale = scale_checkScaleNum(gv_scales,0|SCALE_REL) & SCALE_VAL;
+
+       for (j=0; gv_scales[j]; j++)
+          if (fabs(gv_scales[j]->scale+2) <= 0.001)
+	  {
+	     gv_scale = j;
+	     break;
+          }
+       gv_ascale = sqrt(ascale_p);
+    }
+    else
+    {
+       if (app_res.scale < 0) app_res.scale = (-app_res.scale)|SCALE_MIN;
+       app_res.scale &= (SCALE_VAL|SCALE_MIN);
+       gv_scale = scale_checkScaleNum(gv_scales,app_res.scale|SCALE_REL);
+       if (gv_scale < 0) gv_scale = scale_checkScaleNum(gv_scales,0|SCALE_REL);
+       gv_scale &= SCALE_VAL;
+    }
     if (app_res.scale_base<1) app_res.scale_base = 1;
     app_res.scale_base &= SCALE_VAL;
     gv_scale_base = scale_checkScaleNum(gv_scales,(app_res.scale_base-1)|SCALE_BAS);
@@ -1031,6 +1136,7 @@ int main(argc, argv)
             XtSetArg(args[n], XtNsafer,b);                              n++;
             b = gv_gs_quiet ? True : False;
             XtSetArg(args[n], XtNquiet,b);                              n++;
+            XtSetArg(args[n], XtNinfoVerbose,gv_infoVerbose);           n++;
             b = app_res.use_bpixmap ? True : False;
             XtSetArg(args[n], XtNuseBackingPixmap,b);                   n++;
             XtSetArg(args[n], XtNarguments,gv_gs_arguments);            n++;
@@ -1188,6 +1294,21 @@ int main(argc, argv)
     /* must allow control to resize */
     AaaWidgetAllowResize((AaaWidget)control,True,True);
 
+    if (fullscreen_p) {
+      Atom net_wm_state;
+
+      net_wm_state = XInternAtom(XtDisplay(toplevel), "_NET_WM_STATE", True);
+      if (net_wm_state != None) {
+        Atom wm_fullstate;
+        wm_fullstate = XInternAtom(XtDisplay(toplevel), "_NET_WM_STATE_FULLSCREEN", False);
+
+        XtRealizeWidget(toplevel);
+        XChangeProperty(XtDisplay(toplevel), XtWindow(toplevel),
+                        net_wm_state, XA_ATOM, 32, PropModeReplace,
+                        (unsigned char *)&wm_fullstate, 1);
+      }
+    }
+
     INFMESSAGE(mapping toplevel)
     XtMapWidget(toplevel);
   }
@@ -1271,6 +1392,11 @@ void main_setGhostscriptResources(db)
   if (!strcasecmp(s,"true"))  gv_gs_safer = 1; else gv_gs_safer = 0;
   s = resource_getResource(db,gv_class,gv_name,"gsQuiet",NULL);
   if (!strcasecmp(s,"true"))  gv_gs_quiet = 1; else gv_gs_quiet = 0;
+  s = resource_getResource(db,gv_class,gv_name,"infoVerbose",NULL);
+  if (!strcasecmp(s, "Silent"))      gv_infoVerbose=0;
+  else if (!strcasecmp(s, "Errors")) gv_infoVerbose=1;
+  else if (!strcasecmp(s, "All"))    gv_infoVerbose=2;
+  else gv_infoVerbose = 1;
   ENDMESSAGE(main_setGhostscriptResources)
 }
 
@@ -1297,7 +1423,7 @@ void main_setResolutions(query)
    main_createScaleMenu
 ##################################################*/
 
-void main_createScaleMenu()
+void main_createScaleMenu(void)
 {
   Arg args[1];
   Cardinal n;
@@ -1315,8 +1441,8 @@ void main_createScaleMenu()
       have_line=True;
     }
     scaleEntry[i] = XtCreateManagedWidget(gv_scales[i]->name, smeBSBObjectClass,scaleMenu,args,n);
-    if (gv_scales[i]->is_base) XtAddCallback(scaleEntry[i], XtNcallback,cb_setScale,(XtPointer)(i|SCALE_BAS));
-    else XtAddCallback(scaleEntry[i], XtNcallback,cb_setScale,(XtPointer)(i|SCALE_ABS));
+    if (gv_scales[i]->is_base) XtAddCallback(scaleEntry[i], XtNcallback,cb_setScale,(XtPointer)(intptr_t)(i|SCALE_BAS));
+    else XtAddCallback(scaleEntry[i], XtNcallback,cb_setScale,(XtPointer)(intptr_t)(i|SCALE_ABS));
   }
   ENDMESSAGE(main_createScaleMenu)
 }
