@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -29,7 +29,8 @@
 **           GNU Project
 **
 */
- 
+#include "ac_config.h"
+
 /*
 #define MESSAGES
 */
@@ -96,7 +97,7 @@ void miscmenu_freeMiscMenuEntries(entries)
   miscmenu_parseMiscMenuEntries
 ##################################################*/
 
-static MiscMenuEntry miscmenu_mallocMiscMenuEntry()
+static MiscMenuEntry miscmenu_mallocMiscMenuEntry(void)
 {
   MiscMenuEntry entry;
   entry = (MiscMenuEntry) GV_XtMalloc(sizeof(MiscMenuEntryStruct));
