@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -53,6 +53,7 @@
  * ###jp### 04/96
  * 
  */
+#include "ac_config.h"
 #define USE_ACROREAD_WORKAROUND
 
 /*
@@ -68,6 +69,8 @@
 
 #include <string.h>
 
+#include <sys/stat.h>
+
 #ifndef SEEK_SET
 #define SEEK_SET 0
 #endif
@@ -267,7 +270,7 @@ static char    *empty_string = "";
  *      The Prolog should end with %%EndProlog, however the proglog implicitly
  *      ends when %%BeginSetup, %%Page, %%Trailer or %%EOF are encountered.
  *
- *      The Setup section is where the version 2 page defaults are found.
+ *      The Setup section is where the version 3 page defaults are found.
  *      This section either explicitly begins with %%BeginSetup or implicitly
  *      with any nonblank line after the Prolog.
  *
@@ -308,7 +311,7 @@ static char    *empty_string = "";
 
 /*-----------------------------------------------------------*/
 
-static void ps_dynMemExhaust()
+static void ps_dynMemExhaust(void)
 {
    fprintf(stderr,"Fatal Error: Dynamic memory exhausted.\n");
    exit(EXIT_STATUS_FATAL);
@@ -1455,7 +1458,7 @@ ps_gettext(line, next_char)
         /* Delete trailing ')' */
         if (*line)
           {
-            *line++;
+            line++;
           }
     } else {
         while (*line && !(*line == ' ' || *line == '\t' || *line == '\n')) {
